/**
 ** A Virtual Host Monitor
 **
 ** Copyright 2009 Gary Wuertz gary@issiweb.com
 **
 ** This program is free software: you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
 ** the Free Software Foundation, either version 3 of the License, or
 ** (at your option) any later version.
 **
 ** This program is distributed in the hope that it will be useful,
 ** but WITHOUT ANY WARRANTY; without even the implied warranty of
 ** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 ** GNU General Public License for more details.
 **
 ** You should have received a copy of the GNU General Public License
 ** along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
#ifndef TOPVHOST_VHOST_H
#define TOPVHOST_VHOST_H

#include <map>
#include <string>

#include "topvhost.h"
/**
 * Representation of a vhost
 */
class vhost {
public:
  enum {                                    // reserved fields
    PARSE_FIELD,
    FILE_FIELD,
    OUTPUT_FIELDS
  };
  std::vector<std::string>  fields;         // parse space, file, domain, and data
  int                       nidx;           // index of domain name in fields
  bool                      dirty;          // dirty bit
  bool                      iq;             // parser: quote flag
  int                       argn;           // parser: record number
  int                       hits;           // hits this domain
  int                       wd;             // notify displacement
  off_t                     fsz;            // size of log file
  time_t                    ldtm;           // time of last access
  long                      meter;          // for metering

  vhost() : dirty(false),iq(false),argn(0),hits(0),wd(0),fsz(0),ldtm(0),meter(0) { }
  std::string               filepath(void);
  const char*               filestr(void);
  void                      parseLogRecord(topvhost *info,char *s, int ct);
  bool                      setClean(topvhost *info);
  bool                      setDirty(bool init=true);
  void                      setString(topvhost *info);
  static void               setVector(topvhost *info);
};
#endif
